# Datasets

This is a browser for specific datasets.

To download datasets, run:

    gramex setup datasets

To run the app:

    gramex run datasets

## Add a dataset

- Add to [Google Drive](https://drive.google.com/drive/folders/1_ZeUQW1EqoeSYn5i__SWvX5-bIuISgAz)
  as a SQLite database, compressed using `xz`.
- Add a link to [gramex.yaml](gramex.yaml) under `url.datasets/list.kwargs.datasets`
- Add the relevant FormHandlers

## Docker setup

TBD
